@@ -3,7 +3,7 @@ from requests import request
 from api_manager.constants import Project
 from api_manager.exeptions import NotConfiguredException
 from api_manager.headers import HeadersTemplates, PROJECT_HEADERS
-from api_manager.utils import logging_response
+from api_manager.logger import logging_response
 
 
 def basic_request(
